Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1145)

Unified Diff: content/browser/frame_host/render_frame_host_manager.cc

Issue 298133002: Don't ensure, in single-process mode, that WebUI render views are the only ones in the process, as … (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Set --single-process flag too in order to make sure correct scenario is trigerred Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/render_frame_host_manager.cc
diff --git a/content/browser/frame_host/render_frame_host_manager.cc b/content/browser/frame_host/render_frame_host_manager.cc
index 0663346d8ce240e2b519724cc500d4d0b7f5a644..5ca9dea9a0ca20e1c8fa0de94a35d8f9ef427ae0 100644
--- a/content/browser/frame_host/render_frame_host_manager.cc
+++ b/content/browser/frame_host/render_frame_host_manager.cc
@@ -1223,8 +1223,9 @@ bool RenderFrameHostManager::InitRenderView(
render_view_host->AllowBindings(pending_web_ui()->GetBindings());
} else {
// Ensure that we don't create an unprivileged RenderView in a WebUI-enabled
- // process unless it's swapped out.
- if (!render_view_host->IsSwappedOut()) {
+ // process unless it's swapped out or we run in single-process mode.
+ bool is_single_process = RenderProcessHost::run_renderer_in_process();
nasko 2014/09/29 22:21:48 nit: why create a local variable when you can just
Krzysztof Olczyk 2014/10/01 10:17:47 Done
+ if (!render_view_host->IsSwappedOut() && !is_single_process) {
CHECK(!ChildProcessSecurityPolicyImpl::GetInstance()->HasWebUIBindings(
render_view_host->GetProcess()->GetID()));
}

Powered by Google App Engine
This is Rietveld 408576698